@@ -30,11 +30,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.27
+Version v3.0.28
 
 =cut
 
-our $VERSION = version->declare("v3.0.27");
+our $VERSION = version->declare("v3.0.28");
 
 =head1 SYNOPSIS
 
@@ -627,11 +627,12 @@ sub parse_license
 
 	# MIT
 	given ($licensetext) {
-		when ( /$L{re}{'mit_oldstyle'}/) {
-			$gen_license->('mit_oldstyle');
+		foreach my $id (qw<curl icu isc mit_advertising mit_enna mit_feh mit_new mit_old mit_oldstyle mit_oldstyle_disclaimer mit_oldstyle_permission>) {
+			when ( /$L{re}{$id}/) {
+				$gen_license->($id);
+				continue;
+			}
 		}
-	}
-	given ($licensetext) {
 		when ( /$L{re}{dsdp}/) {
 			$gen_license->('dsdp');
 		}
@@ -642,36 +643,6 @@ sub parse_license
 			$gen_license->('ntp');
 		}
 	}
-	given ($licensetext) {
-		when ( /$L{re}{curl}/) {
-			$gen_license->('curl');
-		}
-	}
-	given ($licensetext) {
-		when ( /$L{re}{mit_oldstyle_disclaimer}/) {
-			$gen_license->('mit_oldstyle_disclaimer');
-		}
-	}
-	given ($licensetext) {
-		when ( /$L{re}{mit_oldstyle_permission}/) {
-			$gen_license->('mit_oldstyle_permission');
-		}
-	}
-	given ($licensetext) {
-		when ( /$L{re}{mit_new}/) {
-			$gen_license->('mit_new');
-		}
-		when ( /$L{re}{'mit_old'}/ ) {
-			$gen_license->('mit_old');
-		}
-	}
-
-	# ISC
-	given ($licensetext) {
-		when ( /Permission to use, copy, modify, and(\/or)? distribute this software for any purpose with or without fee is hereby granted, provided.*copyright notice.*permission notice.*all copies/ ) {
-			$gen_license->('ISC');
-		}
-	}
 
 	# BSD
 	if ( $licensetext =~ /THIS SOFTWARE IS PROVIDED .*AS IS AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY/ ) {
