@@ -11,11 +11,11 @@ Regexp::Pattern::License - Regular expressions for legal licenses
 
 =head1 VERSION
 
-Version v3.0.27
+Version v3.0.28
 
 =cut
 
-our $VERSION = version->declare("v3.0.27");
+our $VERSION = version->declare("v3.0.28");
 
 =head1 DESCRIPTION
 
@@ -110,12 +110,20 @@ Patterns each covering a single license.
 
 =item * gpl
 
+=item * isc
+
 =item * lgpl
 
 =item * llgpl
 
 =item * libpng
 
+=item * mit_advertising
+
+=item * mit_enna
+
+=item * mit_feh
+
 =item * mit_new
 
 =item * mit_new_materials
@@ -234,14 +242,16 @@ our %RE = (
 		'name.alt.org.debian' => 'BSD-2-clause',
 		caption               => 'BSD (2 clause)',
 		tags                  => ['bsd'],
-		pat => qr/$P{repro_notice_cond_discl}\b[^a-zA-Z]+$P{discl}/,
+		pat =>
+			qr/$P{note_repro_notice_cond_discl}\b[^a-zA-Z]+$P{asis_sw_by_name}/,
 	},
 	bsd_3_clause => {
 		name                  => 'BSD-3-Clause',
 		'name.alt.org.debian' => 'BSD-3-clause',
 		caption               => 'BSD (3 clause)',
 		tags                  => ['bsd'],
-		pat => qr/$P{repro_notice_cond_discl}\b[^a-zA-Z]+$P{promo_no_author}/,
+		pat =>
+			qr/$P{note_repro_notice_cond_discl}\b[^a-zA-Z]+$P{nopromo_neither}/,
 	},
 	bsd_4_clause => {
 		name                  => 'BSD-4-Clause',
@@ -368,17 +378,17 @@ our %RE = (
 		name => 'Cube',
 		tags => ['zlib'],
 		pat =>
-			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{retain_notice}.*?$P{derive_no_relicense}/,
+			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{note_invar}.*?$P{derive_no_relicense}/,
 	},
 	curl => {
 		tags => ['mit'],
-		pat =>
-			qr/Permission to use, copy, modify, and distribute this software for/,
+		pat  => qr/$P{note_cpyr_perm}\.\s+$P{asis_sw_warranty}/,
 	},
 	dsdp => {
-		name => 'DSDP',
-		tags => ['mit'],
-		pat  => qr/This program discloses material protectable/,
+		name                     => 'DSDP',
+		'caption.alt.org.fedora' => 'DSDP a.k.a. MIT (PetSC variant)',
+		tags                     => ['mit'],
+		pat => qr/This program discloses material protectable/,
 	},
 	epl => {
 		name    => 'EPL',
@@ -389,7 +399,7 @@ our %RE = (
 		name => 'Eurosym',
 		tags => ['zlib'],
 		pat =>
-			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{derive_share}.*?$P{retain_notice}/,
+			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{derive_share}.*?$P{note_invar}/,
 	},
 	fsfap => {
 		name    => 'FSFAP',
@@ -431,6 +441,17 @@ our %RE = (
 		summary => 'The GNU General Public License',
 		pat     => qr/$the?$gnu?(?:$gpl(?: \(GPL\))?$by_fsf?|GPL)/,
 	},
+	isc => {
+		name => 'ISC',
+		tags => ['mit'],
+		pat  => qr/$P{note_cpyr_perm}\.\s+$P{asis_sw_name_discl}/,
+	},
+	icu => {
+		name => 'ICU',
+		tags => ['mit'],
+		pat =>
+			qr/$P{note_cpyr_perm} of the Software and that $P{note_cpyr_perm_doc}\.\s+$P{asis_sw_warranty}(?:[^.]+\.\s+){2}$P{nopromo_except}/,
+	},
 	lgpl => {
 		name    => 'LGPL',
 		summary => 'The GNU Lesser General Public License',
@@ -446,14 +467,32 @@ our %RE = (
 		name => 'Libpng',
 		pat  => qr/$the?libpng license/,
 	},
+	mit_advertising => {
+		name    => 'MIT-advertising',
+		caption => 'MIT (advertising)',
+		tags    => ['mit'],
+		pat     => qr/$P{note_marketing}\b[^.,]+, and $P{ad_ack_doc_sw}/,
+	},
+	mit_enna => {
+		name    => 'MIT-enna',
+		caption => 'MIT (enna)',
+		tags    => ['mit'],
+		pat     => qr/$P{ad_pub_ack_nosrc}/,
+	},
+	mit_feh => {
+		name    => 'MIT-feh',
+		caption => 'MIT (feh)',
+		tags    => ['mit'],
+		pat     => qr/$P{ad_ack_doc_pkg}/,
+	},
 	mit_new => {
 		'name.alt.org.spdx'      => 'MIT',
 		'name.alt.org.debian'    => 'Expat',
 		caption                  => 'MIT (Expat)',
 		'caption.alt.org.debian' => 'MIT/X11 (BSD like)',
+		'caption.alt.org.fedora' => 'MIT (Modern Style with sublicense)',
 		tags                     => ['mit'],
-		pat =>
-			qr/$P{permission_person_sw_doc}, $P{permission_use_deal_sw}|opensource\.org:?\/licenses\/mit-license\.php/,
+		pat => qr/$P{right_mod_sublic}\b[^.]+\s+$P{note_cpyr_perm_subst}/,
 	},
 	mit_new_materials => {
 		'name.alt.org.debian' => 'MIT~Khronos',
@@ -482,12 +521,12 @@ END
 		'name.alt.org.debian' => 'MIT~oldstyle~disclaimer',
 		caption               => 'MIT (Old Style, legal disclaimer)',
 		tags                  => ['mit'],
-		pat => qr/supporting documentation\.\s+$P{discl_provide}/,
+		pat => qr/supporting documentation\.\s+$P{asis_name_sw}/,
 	},
 	mit_oldstyle_permission => {
 		'name.alt.org.debian' => 'MIT~oldstyle~permission',
 		tags                  => ['mit'],
-		pat                   => qr/$P{name_no_ad}\.\s+$P{discl_provide}/,
+		pat => qr/$P{nopromo_written_prior}\.\s+$P{asis_name_sw}/,
 	},
 	mpl => {
 		name    => 'MPL',
@@ -510,13 +549,13 @@ END
 	ntp => {
 		name => 'NTP',
 		tags => ['mit'],
-		pat  => $P{provided_no_warranty},
+		pat  => $P{asis_expr_warranty},
 	},
 	ntp_disclaimer => {
 		'name.alt.org.debian' => 'NTP~disclaimer',
 		caption               => 'NTP (legal disclaimer)',
 		tags                  => ['mit'],
-		pat => qr/$P{provided_no_warranty}\.\s+$P{discl_disclaim}/,
+		pat => qr/$P{asis_expr_warranty}\.\s+$P{discl_name_warranties}/,
 	},
 	openssl => {
 		name    => 'OpenSSL',
@@ -573,7 +612,7 @@ END
 		caption => 'zlib/libpng',
 		tags    => ['zlib'],
 		pat =>
-			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{retain_notice}/,
+			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{note_invar}/,
 	},
 	zlib_acknowledgement => {
 		name    => 'zlib-acknowledgement',
@@ -599,8 +638,6 @@ Patterns each covering a single trait occuring in licenses.
 
 =item * clause_non_endorsement
 
-=item * disclaimer
-
 =item * fsf_unlimited
 
 =item * fsf_unlimited_retention
@@ -622,13 +659,13 @@ Patterns each covering a single trait occuring in licenses.
 $RE{'clause_retention'} = {
 	caption => 'retention clause',
 	tags    => ['trait'],
-	pat     => qr/$P{retain_notice_cond_discl}/,
+	pat     => qr/$P{note_retain_notice_cond_discl}/,
 };
 
 $RE{'clause_reproduction'} = {
 	caption => 'reproduction clause',
 	tags    => ['trait'],
-	pat     => qr/$P{repro_notice_cond_discl}/,
+	pat     => qr/$P{note_repro_notice_cond_discl}/,
 };
 
 $RE{'clause_advertising'} = {
@@ -646,12 +683,7 @@ $RE{'clause_advertising_always'} = {
 $RE{'clause_non_endorsement'} = {
 	caption => 'non-endorsement clause',
 	tags    => ['trait'],
-	pat     => qr/$P{promo_no_author}/,
-};
-
-$RE{'disclaimer'} = {
-	tags => ['trait'],
-	pat  => qr/$P{discl}/,
+	pat     => qr/$P{nopromo_neither}/,
 };
 
 $RE{'fsf_unlimited'} = {
@@ -735,7 +767,7 @@ $RE{'bsd'} = {
 	caption => 'BSD (unspecified)',
 	tags    => ['group'],
 	pat =>
-		qr/$P{repro_notice_cond_discl}(?:(?:[^a-zA-Z]+$P{ad_verbatim}.*)?[^a-zA-Z]+$P{promo_no_author})?/,
+		qr/$P{note_repro_notice_cond_discl}(?:(?:[^a-zA-Z]+$P{ad_verbatim}.*)?[^a-zA-Z]+$P{nopromo_neither})?/,
 };
 
 $RE{'gnu'} = {
